JSON Schema Converter
======================

``inverter`` provides converter from ``dataclass`` to `JSON Schema <https://json-schema.org/>`_ 
through `Python JSL library <https://jsl.readthedocs.io/en/latest/>`_ 

.. autofunction:: inverter.dc2jsl.convert